Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/hoparound.py
diff options
context:
space:
mode:
Diffstat (limited to 'hoparound.py')
-rw-r--r--hoparound.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/hoparound.py b/hoparound.py
index 357ea0e..56d87a3 100644
--- a/hoparound.py
+++ b/hoparound.py
@@ -3,7 +3,7 @@
This file is part of HopAround.
HopAround is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
@@ -14,7 +14,7 @@
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with Foobar. If not, see <http://www.gnu.org/licenses/>.
+ along with Hop-A-Round. If not, see <http://www.gnu.org/licenses/>.
"""
from sugar.activity import activity
@@ -48,9 +48,9 @@ class HopaRoundActivity(activity.Activity):
def setup(self, data, ui):
data.gen_random()
- ui.set_rounding_phrase(self.data)
- ui.set_choices(self.data.random_number, self.data.mult)
- ui.set_tab(self.data)
+ ui.set_rounding_phrase(data)
+ ui.set_choices(data.random_number, data.mult)
+ ui.set_tab(data)
def submit_answer(self, widget, answer):
try: # for int answer because of entry field
@@ -3,7 +3,7 @@
This file is part of HopAround.
- HopAround is free software: you can redistribute it and/or modify
+ Hop-A-Round is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or